@@ -142,7 +142,8 @@ pub struct EventStream<S> {
 }
 
 impl<S> EventStream<S> {
-    pub(crate) fn new(stream: S) -> Self {
+    /// Initialize the EventStream with a Stream
+    pub fn new(stream: S) -> Self {
         Self {
             stream: Utf8Stream::new(stream),
             buffer: String::new(),
@@ -152,6 +153,12 @@ impl<S> EventStream<S> {
         }
     }
 
+    /// Set the last event ID of the stream. Useful for initializing the stream with a previous
+    /// last event ID
+    pub fn set_last_event_id(&mut self, id: impl Into<String>) {
+        self.last_event_id = id.into();
+    }
+
     /// Get the last event ID of the stream
     pub fn last_event_id(&self) -> &str {
         &self.last_event_id
